import EntityFormColumn from 'model/EntityFormColumn';
import BooleanInputBlock from 'molecules/BooleanInputBlock';
import JoinSelectBlock from 'molecules/JoinSelectBlock';
import KeyValueTableBlock from 'molecules/KeyValueTableBlock';
import LabelBlock from 'molecules/LabelBlock';
import MultiNumberInputBlock from 'molecules/MultiNumberInputBlock';
import NumberInputBlock from 'molecules/NumberInputBlock';
import RadioSelectBlock from 'molecules/RadioSelectBlock';
import StringInputBlock from 'molecules/StringInputBlock';
import TextareaBlock from 'molecules/TextareaBlock';
import TimeSelectBlock from 'molecules/TimeSelectBlock';
import UrlSelectBlock from 'molecules/UrlSelectBlock';
import { convertDateString } from 'service/utility';

const EntityFormBlock = ({ keyValueRecord, cloudContext, formData, setFormData }: {
  keyValueRecord: EntityFormColumn,
  cloudContext: string,
  formData: Record<string, any>,
  setFormData: (v: Record<string, any>) => void,
}) => {

  if (keyValueRecord.type === 'time') {
    const setHour = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.hourName] = v;
      setFormData(newFormData);
    }

    const setMinute = <T,>(v: T) => {
      const newFormData = JSON.parse(JSON.stringify(formData));
      newFormData[keyValueRecord.minuteName] = v;
      setFormData(newFormData);
    }

    return <TimeSelectBlock
      label={keyValueRecord.labelName}
      hour={formData[keyValueRecord.hourName]}
      setHour={setHour}
      minute={formData[keyValueRecord.minuteName]}
      setMinute={setMinute}
      required={!!keyValueRecord.required}
      readOnly={!!keyValueRecord.readOnly} />;
  }

  const value = formData[keyValueRecord.name];

  const setValue = <T,>(v: T) => {
    const newFormData = JSON.parse(JSON.stringify(formData));
    newFormData[keyValueRecord.name] = v;
    setFormData(newFormData);
  }

  switch (keyValueRecord.type) {
    case 'default':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={value} />
        : <StringInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number':
      return !!keyValueRecord.readOnly
        ? <LabelBlock
          name={keyValueRecord.labelName}
          value={`${value}`} />
        : <NumberInputBlock
          label={keyValueRecord.labelName}
          value={value}
          setValue={setValue}
          required={!!keyValueRecord.required}
          readOnly={!!keyValueRecord.readOnly} />;
    case 'number-array':
      return <MultiNumberInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'join':
      return <JoinSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        entityTypeId={keyValueRecord.info.entityTypeId}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'select':
      return <UrlSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        url={keyValueRecord.url}
        cloudContext={cloudContext}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'textarea':
      return <TextareaBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'key-value':
      return <KeyValueTableBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'check':
      return <BooleanInputBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={setValue}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'radio':
      return <RadioSelectBlock
        label={keyValueRecord.labelName}
        value={value}
        setValue={(s: string) => {
          setValue(s);
        }}
        valueList={keyValueRecord.value}
        orientation={keyValueRecord.orientation}
        required={!!keyValueRecord.required}
        readOnly={!!keyValueRecord.readOnly} />;
    case 'datetime':
      return <LabelBlock
        name={keyValueRecord.labelName}
        value={convertDateString(value)} />;
    default:
      return <></>;
  }
}

export default EntityFormBlock;
