import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import EntityData from 'model/EntityData';
import LabelBlock from 'molecules/LabelBlock';
import SelectBlock from 'molecules/SelectBlock';
import { useEffect, useState } from 'react';

/**
 * Block of select view.
 *
 * @param
 */
const JoinSelectBlock = ({ label, value, setValue, entityTypeId, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  entityTypeId: string,
  required: boolean,
  readOnly: boolean,
}) => {

  const { getEntityListAll } = useDrupalJsonApi();
  const [dataList, setDataList] = useState<EntityData[]>([]);

  useEffect(() => {
    getEntityListAll(entityTypeId).then((entityDataList) => {
      setDataList(entityDataList);
    })
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (readOnly) {
    const filtered = dataList.filter((d) => d.attributes['name'] === value);
    return <LabelBlock
      name={label}
      value={filtered.length >= 1 ? filtered[0].attributes['name'] : value} />;
  }

  return <SelectBlock
    label={label}
    value={value}
    setValue={setValue}
    recordList={dataList.map((d) => {
      return { value: d.attributes['name'], label: d.attributes['name'] };
    })}
    required={required} />;

}

export default JoinSelectBlock;
