<?php

namespace Drupal\aws_cloud\Service;

use Drupal\aws_cloud\Service\CloudFormation\CloudFormationServiceInterface;
use Drupal\cloud\Service\CloudOrchestratorManagerInterface;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * AWS Cloud cloud orchestrator manager.
 */
class AwsCloudCloudOrchestratorManager implements CloudOrchestratorManagerInterface {

  use CloudContentEntityTrait;

  /**
   * The CloudFormation Service.
   *
   * @var \Drupal\aws_cloud\Service\CloudFormation\CloudFormationServiceInterface
   */
  protected $cloudFormationService;

  /**
   * Entity field manager interface.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The Entity Type Manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The AwsCloudCloudOrchestratorManager constructor.
   *
   * @param \Drupal\aws_cloud\Service\CloudFormation\CloudFormationServiceInterface $cloud_formation_service
   *   The CloudFormation Service.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(
    CloudFormationServiceInterface $cloud_formation_service,
    EntityFieldManagerInterface $entity_field_manager,
    EntityTypeManagerInterface $entity_type_manager) {

    $this->cloudFormationService = $cloud_formation_service;
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;

    $this->messenger();
  }

  /**
   * {@inheritdoc}
   */
  public function deploy($cloud_context, $manifest, $parameters): void {
    $this->cloudFormationService->setCloudContext($cloud_context);

    $stack_name = $parameters['StackName'];
    unset($parameters['StackName']);

    $cloud_formation_params = [];
    foreach ($parameters as $key => $value) {
      $cloud_formation_params[] = [
        'ParameterKey' => $key,
        'ParameterValue' => $value,
      ];
    }

    $this->cloudFormationService->createStack([
      'StackName' => $stack_name,
      'Capabilities' => [
        'CAPABILITY_NAMED_IAM',
        'CAPABILITY_AUTO_EXPAND',
      ],
      'TemplateBody' => $manifest,
      'Parameters' => $cloud_formation_params,
    ]);
  }

}
