@minimal @ci_job
Feature: Create, read, update and delete a HorizontalPodAutoscaler for K8s as "Authenticated User"

  @api @javascript
  Scenario: Create a HorizontalPodAutoscaler
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler/add"
    And I select "{{ namespace }}" from "Namespace"
    And I fill in "Detail" with:
    """
    apiVersion: autoscaling/v1
    kind: HorizontalPodAutoscaler
    metadata:
      name: {{ horizontalpodautoscaler_name }}
    spec:
      maxReplicas: {{ horizontalpodautoscaler_replica_max }}
      minReplicas: {{ horizontalpodautoscaler_replica_min }}
      scaleTargetRef:
        apiVersion: {{ horizontalpodautoscaler_api }}
        kind: {{ horizontalpodautoscaler_kind }}
        name: {{ horizontalpodautoscaler_scale_name }}
      targetCPUUtilizationPercentage: {{ horizontalpodautoscaler_cpu }}
    """
    And I press "Save"
    And I wait for AJAX to finish
    Then I should be on "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see "{{ namespace }}" in the "{{ horizontalpodautoscaler_name }}" row

  @api @javascript
  Scenario: Read the HorizontalPodAutoscaler
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I click "Refresh"
    And I should see the link "{{ horizontalpodautoscaler_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ horizontalpodautoscaler_name }}"
    Then the url should match "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler/"
    And I should see "{{ horizontalpodautoscaler_name }}"
    And I should see "{{ namespace }}"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Update the HorizontalPodAutoscaler
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I click "Refresh"
    And I should see the link "{{ horizontalpodautoscaler_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ horizontalpodautoscaler_name }}"
    Then the url should match "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler/"
    And I click "Edit"
    """
    apiVersion: autoscaling/v1
    kind: HorizontalPodAutoscaler
    metadata:
      name: {{ horizontalpodautoscaler_name }}
    spec:
      maxReplicas: {{ horizontalpodautoscaler_replica_max_edit }}
      minReplicas: {{ horizontalpodautoscaler_replica_min }}
      scaleTargetRef:
        apiVersion: {{ horizontalpodautoscaler_api }}
        kind: {{ horizontalpodautoscaler_kind }}
        name: {{ horizontalpodautoscaler_scale_name }}
      targetCPUUtilizationPercentage: {{ horizontalpodautoscaler_cpu }}    
    """
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I click "{{ horizontalpodautoscaler_name }}"
    Then the url should match "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler/"
    And I should see "{{ horizontalpodautoscaler_replica_max_edit }}"

  @api @javascript
  Scenario: Delete the HorizontalPodAutoscaler
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I click "Refresh"
    And I should see the link "{{ horizontalpodautoscaler_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ horizontalpodautoscaler_name }}"
    Then the url should match "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler/"
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then I should be on "/clouds/k8s/{{ cloud_context }}/horizontal_pod_autoscaler"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ horizontalpodautoscaler_name }}"
