@minimal @ci_job
Feature: Create and launch a launch template for K8s as "Authenticated User" and
  approve it as "Cloud administrator"

  @api @javascript
  Scenario: Create a Launch template
    Given I am logged in as user "{{ user_name }}"
    When I visit "clouds/design/server_template/{{ cloud_context }}/k8s/add"
    And I enter "{{ launch_git_repository }}" for "Git repository"
    And I wait for AJAX to finish
    And I wait {{ wait }} milliseconds
    And I enter "{{ launch_git_name }}" for "Name"
    And I select "{{ namespace }}" from "Namespace"
    And I click "GIT"
    And I select "Git" from "Source type"
    And I enter "{{ launch_git_resource_path }}" for "Git resource path"
    And I select "{{ launch_git_branch_or_tag }}" from "Git branch or tag"
    And I select "Draft" from "Workflow status"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "{{ launch_git_name }} has been created"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Approve the launch template
    Given I am logged in as a user with the "Cloud administrator" role
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "Edit" in the "{{ launch_git_name }}" row
    And the url should match "/edit"
    And I select "{{ namespace }}" from "Namespace"
    And I select "Approved" from "Workflow status"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "{{ launch_git_name }} has been updated"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Launch a Launch template
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "{{ launch_git_name }}"
    And I click "Launch"
    And the url should match "/launch"
    And I press "Launch"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message" {{ launch_git_pod1 }} has been launched"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Check Launch template deployment
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/deployment"
    And I should see "{{ namespace }}" in the "{{ launch_git_deployment1 }}" row
    And I should see "{{ namespace }}" in the "{{ launch_git_deployment2 }}" row

  @api @javascript
  Scenario: Check Launch template pod
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/pod"
    And I should see "{{ namespace }}" in the "{{ launch_git_pod1 }}" row

  @api @javascript
  Scenario: Delete a Launch template
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "Edit" in the "{{ launch_git_name }}" row
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "{{ launch_git_deployment1 }} (Namespace: {{ namespace }}) on {{ cloud_context }} has been deleted"
    And I should see the success message "{{ launch_git_deployment2 }} (Namespace: {{ namespace }}) on {{ cloud_context }} has been deleted"
    And I should see the success message "{{ launch_git_pod1 }} (Namespace: {{ namespace }}) on {{ cloud_context }} has been deleted"
    And I should see the success message "{{ launch_git_name }} has been deleted"
    And I should see neither error nor warning messages
    And I should not see the link "{{ launch_git_name }}"

  @api @javascript
  Scenario: Check if the Deployment has been deleted
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/deployment"
    Then I should not see "{{ launch_git_deployment1 }}"
    Then I should not see "{{ launch_git_deployment2 }}"

  @api @javascript
  Scenario: Check if the Pod has been deleted
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/pod"
    Then I should not see "{{ launch_git_pod1 }}"
